aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorManoj Gupta <manojgupta@google.com>2017-04-20 13:06:33 -0700
committerManoj Gupta <manojgupta@chromium.org>2017-04-20 20:27:27 +0000
commit4ed81bc349a55c918ae59c7dbe3be0d489d9004c (patch)
tree45b548dc18b080c7deb5af37ce905020b25a3a6d
parent466c45d752af98dae774ecd85c1b07349c292cd9 (diff)
downloadtoolchain-utils-4ed81bc349a55c918ae59c7dbe3be0d489d9004c.tar.gz
Crosperf: Rename chrotomation2.mtv to chrotomation2.svl.
BUG=None Test=Local DUT crosperf run works. Change-Id: I6ef3e3c14a01032be063e963d716a3cc03d576d9 Reviewed-on: https://chromium-review.googlesource.com/483048 Commit-Queue: Manoj Gupta <manojgupta@chromium.org> Tested-by: Manoj Gupta <manojgupta@chromium.org> Trybot-Ready: Manoj Gupta <manojgupta@chromium.org> Reviewed-by: Caroline Tice <cmtice@chromium.org>
-rwxr-xr-xafe_lock_machine.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/afe_lock_machine.py b/afe_lock_machine.py
index 370579db..f83e897b 100755
--- a/afe_lock_machine.py
+++ b/afe_lock_machine.py
@@ -65,7 +65,7 @@ class AFELockManager(object):
changing the lock status of machines on either server. For the ChromeOS
HW Lab, it only allows access to the toolchain team lab machines, as
defined in toolchain-utils/crosperf/default_remotes. By default it will
look for a local server on chrotomation2.mtv.corp.google.com, but an
alternative local AFE server can be supplied, if desired.
!!!IMPORTANT NOTE!!! The AFE server can only be called from the main
@@ -74,7 +74,7 @@ class AFELockManager(object):
in the Python virtual machine (and signal handling) and cannot be changed.
"""
- LOCAL_SERVER = 'chrotomation2.mtv.corp.google.com'
+ LOCAL_SERVER = 'chrotomation2.svl.corp.google.com'
def __init__(self,
remotes,
@@ -65,7 +65,7 @@ class AFELockManager(object):
HW Lab, it only allows access to the toolchain team lab machines, as
defined in toolchain-utils/crosperf/default_remotes. By default it will
- look for a local server on chrotomation2.mtv.corp.google.com, but an
+ look for a local server on chrotomation2.svl.corp.google.com, but an
alternative local AFE server can be supplied, if desired.
!!!IMPORTANT NOTE!!! The AFE server can only be called from the main